@@ -63,58 +63,77 @@ if (class(object)=="cox.aalen")
   xvals<-list();  ant<-rep(0,ptot);  
   for (i in 1:ptot) xvals[[i]]<-c(); 
   rani<-round(runif(1)*10000);
-  test<-matrix(0,n.sim,ptot); uni.test<-matrix(0,n.sim,ptot); 
-  testOBS<-rep(0,4*ptot); 
-                                        # testOBS size and location of supremum, test simulated sup's
-  unitime.test<-time.test<-mult.test<-multtime.test<-test
-  unitime.testOBS<-uni.testOBS<-time.testOBS<-mult.testOBS<-
-    multtime.testOBS<-testOBS
-
-  keepcumz<-c()
+  keepcumz<-c(); k<-0
   for (j in 1:ptot) { 
     z<-unique(covar[,j]); z<-sort(z); 
-    xvals[[j]]<-z; antal<-antal+1; ant[j]<-length(z); 
-    if (ant[j]>2) keepcumz<-c(keepcumz,j); 
-    maxval<-max(maxval,length(z)); }
-  xval<-matrix(0,maxval,ptot); k<-1; 
-  for (i in 1:ptot) {xval[1:ant[i],k]<-xvals[[i]]; k<-k+1;}
+    antal<-antal+1; ant[j]<-length(z); 
+    if (ant[j]>2) { k<-k+1; keepcumz<-c(keepcumz,j); xvals[[k]]<-z;
+        maxval<-max(maxval,length(z)); }
+  }
+
   if (sum(keepcumz)==0 && cum.resid==1) 
     stop(" No continous covariates given to cumulate residuals \n"); 
 
-  univar.proc<-matrix(0,maxval,ptot); 
-  sim.univar.proc<-matrix(0,maxval,50*ptot); 
-  time.proc<-matrix(0,lmgresids,2); sim.time.proc<-matrix(0,lmgresids,50); 
+  pcumz<-length(keepcumz); 
+  test<-matrix(0,n.sim,pcumz); uni.test<-matrix(0,n.sim,pcumz); 
+  testOBS<-rep(0,4*pcumz); 
+  univar.proc<-matrix(0,maxval,pcumz); 
+  robvarcumz<-matrix(0,maxval,pcumz); 
+  sim.univar.proc<-matrix(0,maxval,50*pcumz); 
+  time.proc<-matrix(0,lmgresids,2); 
+  sim.time.proc<-matrix(0,lmgresids,50); 
+  simcumz<-matrix(0,n.sim,pcumz);
+  xval<-matrix(0,maxval,pcumz); 
+  k<-1; 
+  for (i in keepcumz) {xval[1:ant[i],k]<-xvals[[k]]; k<-k+1;}
+
+
+  # testOBS size and location of supremum, test simulated sup's
+  unitime.test<-time.test<-mult.test<-multtime.test<-test
+  unitime.testOBS<-uni.testOBS<-time.testOBS<-mult.testOBS<-
+  multtime.testOBS<-testOBS
+
+  inXorZ<-rep(0,pcumz); 
+  if (pcumz>0) {
+    antX<-(sum(ant[1:px]>2)) 
+    if (antX>0) {inX<-(1:px)[(ant[1:px]>2)]; inXorZ[1:antX]<-1} else {inX<-c();} 
+    if (coxaalen==1) {inZ<-(1:pg)[(ant[(px+1):pg]>2)]; }  else inZ<-c()
+    inXZ<-c(inX,inZ); 
+    inXZ<-inXZ-1
+  } else {inXZ<-0; inXorZ<-0} 
+  ant<-ant[keepcumz]; 
+
 
   if (sum(modelmatrix)==0) {modelmatrix<-0;model<-0;pm<-1;}  else 
   {model<-1; modelmatrix<-as.matrix(modelmatrix); pm<-ncol(modelmatrix); 
    test<-matrix(0,n.sim,3*pm); testOBS<-rep(0,2*pm); 
    covnames<-colnames(modelmatrix); 
- }
+  }
 
   Ut<-cummgt<-matrix(0,lmgresids,pm+1); 
   robvarcum<-matrix(0,lmgresids,pm+1); 
   simUt<-matrix(0,lmgresids,pm*50); 
 
-                                        #dyn.load("linmgresid.so");
+#dyn.load("mgresid.so");
 
   mgout<- .C("mgresid",
-             as.double(X),as.integer(ntot),as.integer(px), 
-             as.integer(antpers),as.double(time),as.double(time2),
-             as.integer(status),as.integer(id),as.double(object$residuals$time),
-             as.integer(lmgresids),as.double(object$residuals$dM),as.integer(n.sim),
-             as.integer(rani),as.double(xval), as.integer(ant), 
-             as.double(univar.proc),as.double(time.proc),as.double(sim.univar.proc),
-             as.double(sim.time.proc),as.double(uni.test),as.double(uni.testOBS),
-             as.double(time.test),as.double(time.testOBS),as.double(unitime.test),
-             as.double(unitime.testOBS),as.double(modelmatrix),as.integer(model),
-             as.integer(pm),as.double(cummgt),as.double(object$residuals$dM.iid),
-             as.double(robvarcum),as.double(testOBS),as.double(test),
-             as.double(simUt),as.double(Ut),as.integer(cum.resid),
-             as.integer(maxval),as.integer(start.design),as.integer(coxaalen),
-             as.double(dcum),as.double(beta),as.double(designG),
-             as.integer(pg),as.double(gamma.iid),as.integer(cluster),
-             as.integer(antclust),PACKAGE="timereg")
-
+     as.double(X),as.integer(ntot),as.integer(px), 
+     as.integer(antpers),as.double(time),as.double(time2),
+     as.integer(status),as.integer(id),as.double(object$residuals$time),
+     as.integer(lmgresids),as.double(object$residuals$dM),as.integer(n.sim),
+     as.integer(rani),as.double(xval), as.integer(ant), 
+     as.double(univar.proc),as.double(time.proc),as.double(sim.univar.proc),
+     as.double(sim.time.proc),as.double(uni.test),as.double(uni.testOBS),
+     as.double(time.test),as.double(time.testOBS),as.double(unitime.test),
+     as.double(unitime.testOBS),as.double(modelmatrix),as.integer(model),
+     as.integer(pm),as.double(cummgt),as.double(object$residuals$dM.iid),
+     as.double(robvarcum),as.double(testOBS),as.double(test),
+     as.double(simUt),as.double(Ut),as.integer(cum.resid),
+     as.integer(maxval),as.integer(start.design),as.integer(coxaalen),
+     as.double(dcum),as.double(beta),as.double(designG),
+     as.integer(pg),as.double(gamma.iid),as.integer(cluster),
+     as.integer(antclust), as.double(robvarcumz), as.double(simcumz),
+     as.integer(inXZ), as.integer(inXorZ),as.integer(pcumz),PACKAGE="timereg")
 
   if (model==1) {
     cum<-matrix(mgout[[29]],lmgresids,pm+1); 
@@ -131,6 +150,7 @@ if (class(object)=="cox.aalen")
       UIt<-list(); for (i in (0:49)*pm) UIt[[i/pm+1]]<-as.matrix(Uit[,i+(1:pm)]);
       testOBS<-mgout[[32]];
       test<-matrix(mgout[[33]],n.sim,3*pm);
+      #simcumz<-matrix(mgout[[48]],n.sim,pcumz);
       testval<-c(); unifCI<-c(); 
       for (i in 1:(2*pm)) testval<-c(testval,pval(test[,i],testOBS[i]))
       for (i in 1:pm) unifCI<-as.vector(c(unifCI,percen(test[,2*pm+i],0.95)));
@@ -152,43 +172,49 @@ if (class(object)=="cox.aalen")
   } 
 
   if (cum.resid>=1) {
-    univar.p<-matrix(mgout[[16]],maxval,ptot)[,keepcumz];
-    univar.p<-as.matrix(univar.p); 
+    univar.p<-matrix(mgout[[16]],maxval,pcumz)
+    #print(univar.p)
+    robvarcumz<-matrix(mgout[[47]],maxval,pcumz)
+    #print(robvarcumz)
+    simcumz<-matrix(mgout[[48]],n.sim,pcumz)
+    #print(sim.cumz); 
     univar.proc<-list(); 
-    k<-1
-    for (i in keepcumz) {
-      univar.proc[[k]]<-cbind(xvals[[i]],univar.p[1:ant[i],k]); 
-      colnames(univar.proc[[k]])<-c(covnames0[i],"cum. martingale residual"); 
-      k<-k+1; 
+    for (i in 1:pcumz) {
+      univar.proc[[i]]<-cbind(xvals[[i]],univar.p[1:ant[i],i]); 
+      colnames(univar.proc[[i]])<-c(covnames0[keepcumz[i]],"cum. martingale residual"); 
     }
-    Uiz<-matrix(mgout[[18]],maxval,50*ptot);
+    Uiz<-matrix(mgout[[18]],maxval,50*pcumz);
     UIz<-list(); 
     k<-1; 
-    for (i in keepcumz) {UIz[[k]]<-matrix(Uiz[1:ant[i],i+(0:49)*ptot],ncol=50);
-                         k<-k+1;}
-    uni.test<-matrix(mgout[[20]],n.sim,ptot)[,keepcumz]; 
+    for (i in 1:pcumz) {
+       UIz[[i]]<-matrix(Uiz[1:ant[i],i+(0:49)*pcumz],ncol=50);
+      k<-k+1;}
+    uni.test<-matrix(mgout[[20]],n.sim,pcumz)
     uni.test<-as.matrix(uni.test); 
-    uni.testOBS<-mgout[[25]][1:ptot][keepcumz]; 
+    uni.testOBS<-mgout[[25]][1:pcumz]; 
     testval<-c(); 
-    lkeep<-length(keepcumz); 
 
-    for (i in 1:lkeep)  testval<-c(testval,pval(uni.test[,i],uni.testOBS[i])) 
+    for (i in 1:pcumz)  testval<-c(testval,pval(uni.test[,i],uni.testOBS[i])) 
+    unifCIz<-c()
+    for (i in 1:pcumz)  unifCIz<-c(unifCIz,percen(simcumz[,i],0.95))
+
     uni.pval<-testval
-    names(uni.testOBS)<- names(uni.pval)<- colnames(uni.test)<-covnames0[keepcumz]; 
-                                        #uni.testOBS<-uni.testOBS[keepcumz]; uni.pval<-uni.pval[keepcumz]
-                                        #uni.test<-uni.test[,keepcumz];
-  } else {
-    uni.testOBS<-uni.pval<-proc.cumz<-UIz<-unitime.pval<-unitime.testOBS<-NULL;}
+    names(uni.testOBS)<-names(uni.pval)<-colnames(uni.test)<-covnames0[keepcumz]; 
+    #uni.testOBS<-uni.testOBS[keepcumz]; uni.pval<-uni.pval[keepcumz]
+    #uni.test<-uni.test[,keepcumz];
+  } else { unifCIz<-uni.testOBS<-uni.pval<-proc.cumz<-UIz<-
+           unitime.pval<-unitime.testOBS<-NULL;}
 
-  ud<-list(cum=cum,robvar.cum=robvar.cum,
+  ud<-list(cum=cum,robvar.cum=robvar.cum,robvar.cumz=robvarcumz,
            pval.testBeq0=pval.testBeq0, obs.testBeq0=obs.testBeq0,
            pval.testBeq0.is=pval.testBeq0.is, obs.testBeq0.is=obs.testBeq0.is,
            sim.testBeq0=sim.testBeq0,
            procBeq0=Ut,sim.test.procBeq0=UIt,
            conf.band=unifCI,
+           conf.band.cumz=unifCIz,
            obs.test=uni.testOBS,pval.test=uni.pval,
            sim.test=uni.test,
-                                        #pval.testtime=unitime.pval,
+           #pval.testtime=unitime.pval,
            proc.cumz=univar.proc,sim.test.proccumz=UIz)
 
   attr(ud,"Call")<-sys.call(); 
@@ -201,16 +227,16 @@ if (class(object)=="cox.aalen")
     object <- x; rm(x);
 	if (!inherits(object, 'cum.residuals')) stop ("Must be an MG resid object")
 
-		cat("  Call: \n")
-			dput(attr(object, "Call"))
-			cat("\n")
+	cat("  Call: \n")
+	dput(attr(object, "Call"))
+	cat("\n")
 }
 
 "plot.cum.residuals" <- function (x,pointwise.ci=1,hw.ci=0,sim.ci=0,
 		robust=1, specific.comps=FALSE,level=0.05, start.time = 0, 
 	stop.time = 0, add.to.plot=FALSE, mains=TRUE, 
 	xlab="Time",ylab ="Cumulative Residuals",ylim=NULL,
-	score=0,...) 
+	score=0,conf.band=FALSE,...) 
 {
   object <- x; rm(x);
   if (!inherits(object,'cum.residuals') ) stop ("Must be output from cum.residuals()") 
@@ -220,7 +246,7 @@ if (class(object)=="cox.aalen")
     if (sum(B)==0)  {
       cat(" To compute cumulative residuals provide model matrix \n");
     } }
-  if (score==2) {
+  if (score==2) { ## {{{
     if (sum(object$obs.test)==0)
       stop("To plot cumulative residuals vs. covariates, cum.resid=1"); 
   }
@@ -268,8 +294,8 @@ if (class(object)=="cox.aalen")
         lines(B[,1],ul,lty=sim.ci,type="s"); 
         lines(B[,1],nl,lty=sim.ci,type="s"); }
       abline(h=0)
-    }
-  } else if (score==1) 
+    } ## }}}
+  } else if (score==1)  ## {{{
     {
                                         # plot score proces
       dim1<-ncol(object$procBeq0)
@@ -292,9 +318,8 @@ if (class(object)=="cox.aalen")
             lines(object$procBeq0[,1],as.matrix(object$sim.test.procBeq0[[j]])[,i-1],
                   col="grey",lwd=1,lty=1)
           lines(object$procBeq0[,1],object$procBeq0[,i],lwd=2)
-        } 
-    } else if (score==2) {
-                                        # plot score proces
+        }  ## }}}
+    } else if (score==2) { ## {{{  plot score proces
       dim1<-length(object$obs.test)
       if (sum(specific.comps)==FALSE) comp<-1:dim1 else comp<-specific.comps
 
@@ -321,9 +346,29 @@ if (class(object)=="cox.aalen")
               if (TYPE=="p") for (j in 1:50)
                 points(object$proc.cumz[[i]][,1],object$sim.test.proccumz[[i]][,j],pch=".")
               lines(object$proc.cumz[[i]][,1],object$proc.cumz[[i]][,2],lwd=2); 
-            } }
-    }
+            } 
+    ## Prediction bandds ## {{{
+    if (conf.band==TRUE) {
+     col.alpha<-0.2
+     col.ci<-"darkblue"
+     lty.ci<-2
+      if (col.alpha==0) col.trans <- col.ci
+      else
+      col.trans <- sapply(col.ci, FUN=function(x) do.call(rgb,as.list(c(col2rgb(x)/255,col.alpha))))
+      if (level!=0.05) c.alpha<-percen(object$sim.test[,i],1-level)
+      else c.alpha<-object$conf.band.cumz[i];
+      t<-object$proc.cumz[[i]][,1]
+      ci<-c.alpha*object$robvar.cumz[1:length(t),i]^.5
+      #print(t); print(ci)
+      lines(t,ci , lwd=1, col=col.ci, lty=lty.ci)
+      lines(t,-ci , lwd=1, col=col.ci, lty=lty.ci)
+      tt <- c(t, rev(t))
+      yy <- c(ci, rev(-ci))
+      polygon(tt,yy, col=col.trans, lty=0)      
+  } ## }}}
+  }
 
+    } ## }}}
 }
 
 "summary.cum.residuals" <-
@@ -331,7 +376,7 @@ function (object,digits=3,...)
 {
   if (!inherits(object, 'cum.residuals')) stop ("Must be an cum.residuals object")
 
-                                        # We print information about object:  
+  # We print information about object:  
   cat("Test for cumulative MG-residuals \n\n")
 
   mtest<-(sum(object$conf.band)>0)
